#include <stdio.h>
#include <local/menu3.h>

MENU tgt_cont_men = {
	0x440,
	0,
	"Cont",
	99,
	-1,
	-1,
	100,
	86,
	0,
	-30584,
	0,
	0,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
};
